@@ -1,20 +1,13 @@
 package MooseX::Types::CheckedUtilExports;
-{
-  $MooseX::Types::CheckedUtilExports::VERSION = '0.41';
-}
-BEGIN {
-  $MooseX::Types::CheckedUtilExports::AUTHORITY = 'cpan:PHAYLON';
-}
+# ABSTRACT: Wrap L<Moose::Util::TypeConstraints> to be safer for L<MooseX::Types>
 
-#ABSTRACT: Wrap L<Moose::Util::TypeConstraints> to be safer for L<MooseX::Types>
+our $VERSION = '0.46';
 
 use strict;
 use warnings;
 use Moose::Util::TypeConstraints ();
 use Moose::Exporter;
-use Sub::Name;
 use Carp;
-
 use namespace::autoclean;
 
 my $StringFoundMsg =
@@ -22,11 +15,37 @@ q{WARNING: String found where Type expected (did you use a => instead of a , ?)}
 
 my @exports = qw/type subtype maybe_type duck_type enum coerce from as/;
 
+#pod =head1 DESCRIPTION
+#pod
+#pod Prevents errors like:
+#pod
+#pod     subtype Foo =>
+#pod     ...
+#pod
+#pod Which should be written as:
+#pod
+#pod     subtype Foo,
+#pod     ...
+#pod
+#pod When using L<MooseX::Types>. Exported by that module.
+#pod
+#pod Exports checked versions of the following subs:
+#pod
+#pod C<type> C<subtype> C<maybe_type> C<duck_type> C<enum> C<coerce> C<from> C<as>
+#pod
+#pod While C<class_type> and C<role_type> will also register the type in the library.
+#pod
+#pod From L<Moose::Util::TypeConstraints>. See that module for syntax.
+#pod
+#pod =cut
 
 for my $export (@exports) {
     no strict 'refs';
 
-    *{$export} = sub {
+    Sub::Install::install_sub({
+      into => __PACKAGE__,
+      as   => $export,
+      code => sub {
         my $caller = shift;
 
         local $Carp::CarpLevel = $Carp::CarpLevel + 1;
@@ -38,7 +57,8 @@ for my $export (@exports) {
                 $caller->get_registered_role_type($_[0]);
 
         goto &{"Moose::Util::TypeConstraints::$export"};
-    }
+      }
+    });
 }
 
 Moose::Exporter->setup_import_methods(
@@ -61,6 +81,11 @@ sub role_type ($;$) {
     );
 }
 
+#pod =head1 SEE ALSO
+#pod
+#pod L<MooseX::Types>
+#pod
+#pod =cut
 
 1;
 
@@ -70,15 +95,13 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Robert "phaylon" Sedlacek
-
 =head1 NAME
 
 MooseX::Types::CheckedUtilExports - Wrap L<Moose::Util::TypeConstraints> to be safer for L<MooseX::Types>
 
 =head1 VERSION
 
-version 0.41
+version 0.46
 
 =head1 DESCRIPTION
 
@@ -106,11 +129,6 @@ From L<Moose::Util::TypeConstraints>. See that module for syntax.
 
 L<MooseX::Types>
 
-=head1 LICENSE
-
-This program is free software; you can redistribute it and/or modify
-it under the same terms as perl itself.
-
 =head1 AUTHOR
 
 Robert "phaylon" Sedlacek <rs@474.at>
