@@ -1,17 +1,33 @@
-package MooseX::Types::Combine;
-{
-  $MooseX::Types::Combine::VERSION = '0.41';
-}
-BEGIN {
-  $MooseX::Types::Combine::AUTHORITY = 'cpan:PHAYLON';
-}
-
-# ABSTRACT: Combine type libraries for exporting
-
 use strict;
 use warnings;
-use Module::Runtime 'use_module';
+package MooseX::Types::Combine;
+# ABSTRACT: Combine type libraries for exporting
 
+our $VERSION = '0.46';
+
+use Module::Runtime 'use_module';
+use namespace::autoclean;
+
+#pod =head1 SYNOPSIS
+#pod
+#pod     package CombinedTypeLib;
+#pod
+#pod     use base 'MooseX::Types::Combine';
+#pod
+#pod     __PACKAGE__->provide_types_from(qw/TypeLib1 TypeLib2/);
+#pod
+#pod     package UserClass;
+#pod
+#pod     use CombinedTypeLib qw/Type1 Type2 ... /;
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod Allows you to export types from multiple type libraries.
+#pod
+#pod Libraries on the right end of the list passed to L</provide_types_from>
+#pod take precedence over those on the left in case of conflicts.
+#pod
+#pod =cut
 
 sub import {
     my ($class, @types) = @_;
@@ -42,6 +58,13 @@ sub import {
         for keys %from;
 }
 
+#pod =head1 CLASS METHODS
+#pod
+#pod =head2 provide_types_from
+#pod
+#pod Sets or returns a list of type libraries to re-export from.
+#pod
+#pod =cut
 
 sub provide_types_from {
     my ($class, @libs) = @_;
@@ -85,6 +108,11 @@ sub _provided_types {
     %$types;
 }
 
+#pod =head1 SEE ALSO
+#pod
+#pod L<MooseX::Types>
+#pod
+#pod =cut
 
 1;
 
@@ -94,15 +122,13 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Robert "phaylon" Sedlacek
-
 =head1 NAME
 
 MooseX::Types::Combine - Combine type libraries for exporting
 
 =head1 VERSION
 
-version 0.41
+version 0.46
 
 =head1 SYNOPSIS
 
@@ -133,11 +159,6 @@ Sets or returns a list of type libraries to re-export from.
 
 L<MooseX::Types>
 
-=head1 LICENSE
-
-This program is free software; you can redistribute it and/or modify
-it under the same terms as perl itself.
-
 =head1 AUTHOR
 
 Robert "phaylon" Sedlacek <rs@474.at>
