@@ -1,31 +1,70 @@
-package MooseX::Types::Moose;
-{
-  $MooseX::Types::Moose::VERSION = '0.41';
-}
-BEGIN {
-  $MooseX::Types::Moose::AUTHORITY = 'cpan:PHAYLON';
-}
-
-# ABSTRACT: Type exports that match the types shipped with L<Moose>
-
 use warnings;
 use strict;
+package MooseX::Types::Moose;
+# ABSTRACT: Type exports that match the types shipped with L<Moose>
+
+our $VERSION = '0.46';
 
 use MooseX::Types;
 use Moose::Util::TypeConstraints ();
 
 use namespace::autoclean;
 
+#pod =head1 SYNOPSIS
+#pod
+#pod   package Foo;
+#pod   use Moose;
+#pod   use MooseX::Types::Moose qw( ArrayRef Int Str );
+#pod   use Carp qw( croak );
+#pod
+#pod   has 'name',
+#pod     is  => 'rw',
+#pod     isa => Str;
+#pod
+#pod   has 'ids',
+#pod     is  => 'rw',
+#pod     isa => ArrayRef[Int];
+#pod
+#pod   sub add {
+#pod       my ($self, $x, $y) = @_;
+#pod       croak 'First arg not an Int'  unless is_Int($x);
+#pod       croak 'Second arg not an Int' unless is_Int($y);
+#pod       return $x + $y;
+#pod   }
+#pod
+#pod   1;
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod This package contains a virtual library for L<MooseX::Types> that
+#pod is able to export all types known to L<Moose>. See L<MooseX::Types>
+#pod for general usage information.
+#pod
+#pod =cut
 
 # all available builtin types as short and long name
 my %BuiltIn_Storage
   = map { ($_) x 2 }
     Moose::Util::TypeConstraints->list_all_builtin_type_constraints;
 
+#pod =head1 METHODS
+#pod
+#pod =head2 type_storage
+#pod
+#pod Overrides L<MooseX::Types::Base>' C<type_storage> to provide a hash
+#pod reference containing all built-in L<Moose> types.
+#pod
+#pod =cut
 
 # use prepopulated builtin hash as type storage
 sub type_storage { \%BuiltIn_Storage }
 
+#pod =head1 SEE ALSO
+#pod
+#pod L<Moose>,
+#pod L<Moose::Util::TypeConstraints>
+#pod
+#pod =cut
 
 1;
 
@@ -35,18 +74,13 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Robert "phaylon" Sedlacek Dave Luehrs John Napiorkowski Justin Hunter Karen
-Etheridge Kent Fredric Matt Rolsky S Trout Paul Fenwick Rafael Kitover
-'phaylon' Tomas Florian Doran (t0m) matthewt Ragwitz Graham Knop Hans
-Dieter Pearcey Jesse
-
 =head1 NAME
 
 MooseX::Types::Moose - Type exports that match the types shipped with L<Moose>
 
 =head1 VERSION
 
-version 0.41
+version 0.46
 
 =head1 SYNOPSIS
 
@@ -87,15 +121,9 @@ reference containing all built-in L<Moose> types.
 
 =head1 SEE ALSO
 
-L<MooseX::Types::Moose>,
 L<Moose>,
 L<Moose::Util::TypeConstraints>
 
-=head1 LICENSE
-
-This program is free software; you can redistribute it and/or modify
-it under the same terms as perl itself.
-
 =head1 AUTHOR
 
 Robert "phaylon" Sedlacek <rs@474.at>
